StateCase<STATE extends Object, ACTION extends Object, MOCKS extends Object> class final

Opaque transition specifications for one source state.

Prefer creating instances through whenInitialStateIs so that tests keep a consistent Given-When-Then shape.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited