expectInvalidTransition<STATE extends Object> function

TransitionExpectation<STATE> expectInvalidTransition<STATE extends Object>()

Expects the dispatched action to be invalid for the source state.

Invalid transitions must emit no states and must leave the StateMachine in the original source state.

Implementation

TransitionExpectation<STATE> expectInvalidTransition<STATE extends Object>() =>
    TransitionExpectation<STATE>._invalid();